/****************************************************************************
    Qt-LCoV Library Editor for Qt-BSch3V
    Copyright (C) 2002-2005 H.Okada

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*****************************************************************************/

#include "prop_comp.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <q3whatsthis.h>
#include <qimage.h>
#include <qpixmap.h>
//Added by qt3to4:
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QGridLayout>

#include "prop_comp.ui.h"
/*
 *  Constructs a prop_comp as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
prop_comp::prop_comp( QWidget* parent, const char* name, bool modal, Qt::WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "prop_comp" );
    setModal( TRUE );
    prop_compLayout = new QVBoxLayout( this, 11, 6, "prop_compLayout"); 

    layout2 = new QHBoxLayout( 0, 0, 6, "layout2"); 

    textLabel1 = new QLabel( this, "textLabel1" );
    layout2->addWidget( textLabel1 );

    editName = new QLineEdit( this, "editName" );
    editName->setMaxLength( 15 );
    layout2->addWidget( editName );

    textLabel2 = new QLabel( this, "textLabel2" );
    layout2->addWidget( textLabel2 );

    editRef = new QLineEdit( this, "editRef" );
    editRef->setMaximumSize( QSize( 100, 32767 ) );
    editRef->setMaxLength( 16 );
    layout2->addWidget( editRef );
    prop_compLayout->addLayout( layout2 );

    layout5 = new QHBoxLayout( 0, 0, 6, "layout5"); 

    layout1 = new QGridLayout( 0, 1, 1, 0, 6, "layout1"); 

    textLabel4 = new QLabel( this, "textLabel4" );

    layout1->addWidget( textLabel4, 1, 0 );

    editHeight = new QLineEdit( this, "editHeight" );
    editHeight->setMaximumSize( QSize( 80, 32767 ) );

    layout1->addWidget( editHeight, 1, 1 );

    textLabel3 = new QLabel( this, "textLabel3" );

    layout1->addWidget( textLabel3, 0, 0 );

    editWidth = new QLineEdit( this, "editWidth" );
    editWidth->setMaximumSize( QSize( 80, 32767 ) );
    editWidth->setMaxLength( 3 );

    layout1->addWidget( editWidth, 0, 1 );
    layout5->addLayout( layout1 );

    layout3 = new QGridLayout( 0, 1, 1, 0, 6, "layout3"); 

    checkUsePtn = new QCheckBox( this, "checkUsePtn" );

    layout3->addMultiCellWidget( checkUsePtn, 1, 1, 0, 1 );

    editBlock = new QLineEdit( this, "editBlock" );
    editBlock->setMaximumSize( QSize( 80, 32767 ) );

    layout3->addWidget( editBlock, 0, 1 );

    textLabel5 = new QLabel( this, "textLabel5" );

    layout3->addWidget( textLabel5, 0, 0 );
    layout5->addLayout( layout3 );

    layout4 = new QVBoxLayout( 0, 0, 6, "layout4"); 

    buttonOK = new QPushButton( this, "buttonOK" );
    layout4->addWidget( buttonOK );

    buttonCancel = new QPushButton( this, "buttonCancel" );
    layout4->addWidget( buttonCancel );
    layout5->addLayout( layout4 );
    prop_compLayout->addLayout( layout5 );
    languageChange();
    resize( QSize(390, 116).expandedTo(minimumSizeHint()) );
//Qt4    clearWState( WState_Polished );

    // signals and slots connections
    connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( close() ) );
    connect( buttonOK, SIGNAL( clicked() ), this, SLOT( onOK() ) );

    // tab order
    setTabOrder( editName, editRef );
    setTabOrder( editRef, editWidth );
    setTabOrder( editWidth, editHeight );
    setTabOrder( editHeight, editBlock );
    setTabOrder( editBlock, checkUsePtn );
    setTabOrder( checkUsePtn, buttonOK );
    setTabOrder( buttonOK, buttonCancel );

    // buddies
    textLabel1->setBuddy( editName );
    textLabel2->setBuddy( editRef );
    textLabel4->setBuddy( editHeight );
    textLabel3->setBuddy( editWidth );
}

/*
 *  Destroys the object and frees any allocated resources
 */
prop_comp::~prop_comp()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void prop_comp::languageChange()
{
    setCaption( tr( "Component Property" ) );
    textLabel1->setText( tr( "Name" ) );
    textLabel2->setText( tr( "Reference" ) );
    textLabel4->setText( tr( "Height" ) );
    textLabel3->setText( tr( "Width" ) );
    checkUsePtn->setText( tr( "Use Pattern" ) );
    textLabel5->setText( tr( "Block" ) );
    buttonOK->setText( tr( "OK" ) );
    buttonCancel->setText( tr( "Cancel" ) );
}

